import { __rest } from '../../_virtual/_tslib.js';
import { jsxs, jsx } from 'react/jsx-runtime';
import { GridIconButton } from '@ezgrid/grid-core';
import { faMinus, faPlus, faExpand, faExpandAlt, faFastBackward, faArrowLeft, faArrowRight, faFastForward, faCog, faSave, faFilter, faChartBar, faThLarge, faChevronDown, faAngleDown, faChevronUp, faAngleUp, faFilePdf, faDownload, faClose, faSyncAlt, faTrashAlt, faCheck, faFilterCircleDollar, faEdit, faCopy, faClipboard, faBuildingColumns, faRoad } from '@fortawesome/free-solid-svg-icons';
import { createElement } from 'react';
import Button from 'react-bootstrap/Button';
import Form from 'react-bootstrap/Form';
import ListGroup from 'react-bootstrap/ListGroup';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

const generateIcon = (icon, {
  onClick,
  disabled,
  title,
  className,
  style
}, textAndIcon) => textAndIcon ? jsxs(Button, Object.assign({
  color: "primary",
  onClick: onClick,
  disabled: disabled,
  title: title,
  style: style,
  variant: "outlined"
}, {
  children: [icon, "  ", title]
}), className) : jsx(Button, Object.assign({
  color: "primary",
  onClick: onClick,
  disabled: disabled,
  title: title,
  style: style
}, {
  children: icon
}), className);
const bootstrapAdapter = {
  createElementFromNode: (node, props, children) => {
    let propsToApply = props;
    if (node.key.indexOf("remove-circle-icon") >= 0) {
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faMinus
      }), props);
    } else if (node.key.indexOf("add-circle-icon") >= 0) {
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faPlus
      }), props);
    } else if (node.key.indexOf("expand-one-icon") >= 0) {
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faExpand
      }), props);
    } else if (node.key.indexOf("collapse-one-icon") >= 0) {
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faExpandAlt
      }), props);
    }
    return /*#__PURE__*/createElement("div", propsToApply, children);
  },
  createSelectField: props => {
    const {
      onChange,
      ref,
      style,
      options,
      value,
      fullWidth
    } = props;
    if ((options === null || options === void 0 ? void 0 : options.length) === 0) return null;
    return jsx(Form.Select, Object.assign({
      onChange: e => {
        onChange === null || onChange === void 0 ? void 0 : onChange(e.target.value);
      },
      style: style,
      ref: ref,
      value: value
    }, {
      children: (options || []).map(option => jsx("option", Object.assign({
        value: option.value
      }, {
        children: option.name
      }), option.value))
    }));
  },
  createDateField: props => {
    const {
      onChange,
      value
    } = props;
    return jsx(Form.Control, {
      type: "date",
      value: value === null || value === void 0 ? void 0 : value.toString().substring(0, 10),
      onChange: e => {
        onChange === null || onChange === void 0 ? void 0 : onChange(new Date(e.target.value));
      }
    });
  },
  createTextField: props => {
    const {
        onChange,
        attributes,
        ref
      } = props,
      rest = __rest(props, ["onChange", "attributes", "ref"]);
    return jsx(Form.Control, Object.assign({
      onChange: e => {
        onChange === null || onChange === void 0 ? void 0 : onChange(e.target.value);
      }
    }, attributes, rest, {
      ref: ref
    }));
  },
  createTextArea: props => {
    const {
        onChange,
        ref,
        attributes
      } = props,
      rest = __rest(props, ["onChange", "ref", "attributes"]);
    return jsx(Form.Control, Object.assign({
      as: "textarea",
      onChange: e => {
        onChange === null || onChange === void 0 ? void 0 : onChange(e.target.value);
      }
    }, attributes, rest, {
      ref: ref
    }));
  },
  createCheckBox: props => {
    const {
      onChange,
      value,
      ref
    } = props;
    return jsx(Form.Check, {
      ref: ref,
      onChange: e => {
        onChange === null || onChange === void 0 ? void 0 : onChange(e.target.checked);
      },
      checked: value === true
    });
  },
  createMenu: props => {
    var _a, _b, _c;
    const {
      options
    } = props;
    const cell = {
      rowIdentifier: ((_a = props.rowPosition) === null || _a === void 0 ? void 0 : _a.uniqueIdentifier) || "",
      columnIdentifier: ((_c = (_b = props.columnPosition) === null || _b === void 0 ? void 0 : _b.column) === null || _c === void 0 ? void 0 : _c.uniqueIdentifier) || ""
    };
    return jsx(ListGroup, Object.assign({
      className: "flex-column"
    }, {
      children: options === null || options === void 0 ? void 0 : options.map((item, idx) => item ? jsx(ListGroup.Item, Object.assign({
        onClick: () => item.onClick(cell)
      }, {
        children: item.label
      }), idx) : jsx(ListGroup.Item, {}, idx))
    }), "menu");
  },
  createTriStateCheckbox: props => {
    return null;
  },
  createIconButton: (icon, {
    props
  }, textAndIcon) => {
    if (icon === GridIconButton.PageFirst) {
      // return generateIcon(<FirstPage />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faFastBackward
      }), props, textAndIcon);
    } else if (icon === GridIconButton.PagePrevious) {
      // return generateIcon(<ArrowBack />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faArrowLeft
      }), props, textAndIcon);
    } else if (icon === GridIconButton.PageNext) {
      // return generateIcon(<ArrowForward />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faArrowRight
      }), props, textAndIcon);
    } else if (icon === GridIconButton.PageLast) {
      // return generateIcon(<LastPage />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faFastForward
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Settings) {
      // return generateIcon(<Settings />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faCog
      }), props, textAndIcon);
    } else if (icon === GridIconButton.SettingsSave) {
      // return generateIcon(<Save />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faSave
      }), props, textAndIcon);
    } else if (icon === GridIconButton.FilterBuilder) {
      // return generateIcon(<FilterList />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faFilter
      }), props, textAndIcon);
    } else if (icon === GridIconButton.ChartBuilder) {
      // return generateIcon(<Addchart />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faChartBar
      }), props, textAndIcon);
    } else if (icon === GridIconButton.SettingsManage) {
      // return generateIcon(<GridView />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faThLarge
      }), props, textAndIcon);
    } else if (icon === GridIconButton.ExpandOne) {
      // return generateIcon(<ExpandMore />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faChevronDown
      }), props, textAndIcon);
    } else if (icon === GridIconButton.ExpandAll) {
      // return generateIcon(<UnfoldMore />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faAngleDown
      }), props, textAndIcon);
    } else if (icon === GridIconButton.CollapseOne) {
      // return generateIcon(<ExpandLess />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faChevronUp
      }), props, textAndIcon);
    } else if (icon === GridIconButton.CollapseAll) {
      // return generateIcon(<UnfoldLess />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faAngleUp
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Pdf) {
      // return generateIcon(<PictureAsPdf />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faFilePdf
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Excel) {
      // return generateIcon(<FileDownload />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faDownload
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Cancel) {
      // return generateIcon(<Cancel />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faClose
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Reset) {
      // return generateIcon(<RestartAlt />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faSyncAlt
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Delete) {
      // return generateIcon(<DeleteOutline />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faTrashAlt
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Ok || icon === GridIconButton.Apply) {
      // return generateIcon(<DoneOutline />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faCheck
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Filter) {
      // return generateIcon(<FilterAlt />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faFilterCircleDollar
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Edit) {
      // return generateIcon(<Edit />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faEdit
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Plus) {
      // return generateIcon(<AddCircle />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faPlus
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Minus) {
      // return generateIcon(<RemoveCircle />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faMinus
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Copy) {
      // return generateIcon(<CopyAll />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faCopy
      }), props, textAndIcon);
    } else if (icon === GridIconButton.Paste) {
      // return generateIcon(<ContentPaste />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faClipboard
      }), props, textAndIcon);
    } else if (icon === GridIconButton.FormulaColumn) {
      // return generateIcon(<AddRoad />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faBuildingColumns
      }), props, textAndIcon);
    } else if (icon === GridIconButton.BulkEdit) {
      // return generateIcon(<EditRoad />, props, textAndIcon);
      return generateIcon(jsx(FontAwesomeIcon, {
        icon: faRoad
      }), props, textAndIcon);
    }
    return {
      props
    };
  }
};

export { bootstrapAdapter, generateIcon };
